PhyClockGuard

Struct PhyClockGuard 

pub struct PhyClockGuard<'d> { /* private fields */ }
Prevents the PHY clock from being disabled.

As long as at least one PhyClockGuard exists, the PHY clock will remain active. To release this guard, you can either let it go out of scope or use PhyClockGuard::release to explicitly release it.

Implementations

Source

impl PhyClockGuard<'_>

pub fn release(self)

Release the clock guard.

The PHY clock will be disabled, if this is the last clock guard.