Struct PhyClockGuard Copy item path Source pub struct PhyClockGuard<'d> { }Expand description Prevents the PHY clock from being disabled.
As long as at least one PhyClockGuard exists, the PHY clock will remain
active. To release this guard, you can either let it go out of scope or use
PhyClockGuard::release to explicitly release it.
Release the clock guard.
The PHY clock will be disabled, if this is the last clock guard.
Formats the value using the given formatter.
Read more Executes the destructor for this type.
Read more Immutably borrows from an owned value.
Read more Mutably borrows from an owned value.
Read more Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.